@@ -34,10 +34,9 @@ if __name__ == '__main__':
 ac_table = {
     'commands': ['--help', '--version', '--version-full', 'hello-world', 'pod', 'flow', 'gateway', 'ping', 'check',
                  'hub', 'pea', 'log', 'client', 'export-api'], 'completions': {
-        'hello-world': ['--help', '--workdir', '--logserver', '--logserver-config', '--download-proxy', '--shards',
-                        '--parallel', '--uses-index', '--index-data-url', '--index-labels-url', '--index-batch-size',
-                        '--uses-query', '--query-data-url', '--query-labels-url', '--query-batch-size', '--num-query',
-                        '--top-k'],
+        'hello-world': ['--help', '--workdir', '--download-proxy', '--shards', '--parallel', '--uses-index',
+                        '--index-data-url', '--index-labels-url', '--index-request-size', '--uses-query',
+                        '--query-data-url', '--query-labels-url', '--query-request-size', '--num-query', '--top-k'],
         'pod': ['--help', '--name', '--log-config', '--identity', '--log-id', '--show-exc-info', '--port-ctrl',
                 '--ctrl-with-ipc', '--timeout-ctrl', '--ssh-server', '--ssh-keyfile', '--ssh-password', '--uses',
                 '--py-modules', '--port-in', '--port-out', '--host-in', '--host-out', '--socket-in', '--socket-out',
@@ -47,8 +46,7 @@ ac_table = {
                 '--timeout-ready', '--env', '--expose-public', '--pea-id', '--pea-role', '--uses-before',
                 '--uses-after', '--parallel', '--shards', '--polling', '--scheduling', '--remote-access',
                 '--remote-type', '--pod-role'],
-        'flow': ['--help', '--uses', '--logserver', '--logserver-config', '--log-id', '--optimize-level',
-                 '--output-type', '--output-path', '--inspect'],
+        'flow': ['--help', '--uses', '--log-id', '--optimize-level', '--output-type', '--output-path', '--inspect'],
         'gateway': ['--help', '--name', '--log-config', '--identity', '--log-id', '--show-exc-info', '--port-ctrl',
                     '--ctrl-with-ipc', '--timeout-ctrl', '--ssh-server', '--ssh-keyfile', '--ssh-password', '--uses',
                     '--py-modules', '--port-in', '--port-out', '--host-in', '--host-out', '--socket-in', '--socket-out',
@@ -78,6 +76,6 @@ ac_table = {
                 '--host', '--port-expose', '--daemon', '--runtime-backend', '--runtime', '--runtime-cls',
                 '--timeout-ready', '--env', '--expose-public', '--pea-id', '--pea-role'],
         'log': ['--help', '--groupby-regex', '--refresh-time'],
-        'client': ['--help', '--batch-size', '--mode', '--top-k', '--mime-type', '--continue-on-error',
+        'client': ['--help', '--request-size', '--mode', '--top-k', '--mime-type', '--continue-on-error',
                    '--return-results', '--max-message-size', '--proxy', '--prefetch', '--prefetch-on-recv', '--restful',
                    '--rest-api', '--host', '--port-expose'], 'export-api': ['--help', '--yaml-path', '--json-path']}}
