@@ -6,14 +6,16 @@ from collections import namedtuple
 
 import pkg_resources
 from fastapi import FastAPI
+from fastapi.middleware.cors import CORSMiddleware
 from uvicorn import Config, Server
 
 from jina.logging import JinaLogger
 from .parser import get_main_parser
 
-daemon_logger = JinaLogger(context='👻', log_config=os.getenv('JINAD_LOG_CONFIG',
-                                                              pkg_resources.resource_filename('jina', '/'.join(
-                                                                  ('resources', 'logging.daemon.yml')))))
+daemon_logger = JinaLogger(context='👻',
+                           log_config=os.getenv('JINAD_LOG_CONFIG',
+                                                pkg_resources.resource_filename(
+                                                    'jina', '/'.join(('resources', 'logging.daemon.yml')))))
 
 
 def _get_app():
@@ -37,6 +39,13 @@ def _get_app():
         description=fastapi_config.DESCRIPTION,
         version=fastapi_config.VERSION
     )
+    app.add_middleware(
+        CORSMiddleware,
+        allow_origins=['*'],
+        allow_credentials=True,
+        allow_methods=['*'],
+        allow_headers=['*'],
+    )
     app.include_router(router=common_router)
     app.include_router(router=logs.router)
     if jinad_config.CONTEXT == 'all':
@@ -67,11 +76,11 @@ def _start_uvicorn(app: 'FastAPI'):
                     log_level='error')
     server = Server(config=config)
     server.run()
-    daemon_logger.info('Bye!')
+    daemon_logger.info('\tGoodbye!')
 
 
 def _start_fluentd():
-    daemon_logger.info('Starting fluentd')
+    daemon_logger.info('\tStarting fluentd')
     cfg = pkg_resources.resource_filename('jina', 'resources/fluent.conf')
     try:
         subprocess.Popen(['fluentd', '-qq', '-c', cfg])
