@@ -37,7 +37,7 @@ __license__ = "Apache-2.0"
 # do not change this line manually
 # this is managed by git tag and updated on every release
 # NOTE: this represents the NEXT release version
-__version__ = '0.9.12'
+__version__ = '0.9.17'
 
 # do not change this line manually
 # this is managed by proto/build-proto.sh and updated on every execution
@@ -100,7 +100,6 @@ from jina.types.sets import DocumentSet, QueryLangSet
 # ADD GLOBAL NAMESPACE VARIABLES
 
 JINA_GLOBAL = _types.SimpleNamespace()
-JINA_GLOBAL.logserver = _types.SimpleNamespace()
 
 import jina.importer as _ji
 
@@ -162,5 +161,14 @@ from jina.flow.asyncio import AsyncFlow
 from jina.clients import Client
 from jina.clients.asyncio import AsyncClient
 
+# Executor
+from jina.executors.classifiers import BaseClassifier as Classifier
+from jina.executors.crafters import BaseCrafter as Crafter
+from jina.executors.encoders import BaseEncoder as Encoder
+from jina.executors.evaluators import BaseEvaluator as Evaluator
+from jina.executors.indexers import BaseIndexer as Indexer
+from jina.executors.rankers import BaseRanker as Ranker
+from jina.executors.segmenters import BaseSegmenter as Segmenter
+
 __all__ = [_s for _s in dir() if not _s.startswith('_')]
 __all__.extend([_s for _s in _names_with_underscore])
