@@ -112,7 +112,8 @@ class BaseExecutor(JAMLCompatible, metaclass=ExecutorType):
 
     """
     store_args_kwargs = False  #: set this to ``True`` to save ``args`` (in a list) and ``kwargs`` (in a map) in YAML config
-    exec_methods = ['encode', 'add', 'query', 'craft', 'segment', 'score', 'evaluate', 'predict', 'query_by_id', 'delete', 'update']
+    exec_methods = ['encode', 'add', 'query', 'craft', 'segment', 'score', 'evaluate', 'predict', 'query_by_id',
+                    'delete', 'update']
 
     def __init__(self, *args, **kwargs):
         if isinstance(args, tuple) and len(args) > 0:
@@ -126,16 +127,6 @@ class BaseExecutor(JAMLCompatible, metaclass=ExecutorType):
         self._drivers = {}  # type: Dict[str, List['BaseDriver']]
         self._attached_pea = None
 
-    def _check_on_gpu(self):
-        if self.on_gpu:
-            try:
-                cuda_version = subprocess.check_output(['nvcc', '--version']).decode()
-                self.logger.success(f'CUDA compiler version: {cuda_version}')
-            except OSError:
-                self.logger.warning(
-                    'on_gpu=True, but you dont have CUDA compatible GPU, i will reset on_gpu=False ')
-                self.on_gpu = False
-
     def _post_init_wrapper(self, _metas: Dict = None, _requests: Dict = None, fill_in_metas: bool = True) -> None:
         with TimeContext('post_init may take some time', self.logger):
             if fill_in_metas:
@@ -149,7 +140,6 @@ class BaseExecutor(JAMLCompatible, metaclass=ExecutorType):
                 self._fill_metas(_metas)
                 self._fill_requests(_requests)
 
-            self._check_on_gpu()
             _before = set(list(vars(self).keys()))
             self.post_init()
             self._post_init_vars = {k for k in vars(self) if k not in _before}
@@ -257,7 +247,7 @@ class BaseExecutor(JAMLCompatible, metaclass=ExecutorType):
         :return: if ``separated_workspace`` is set to ``False`` then ``metas.workspace`` is returned,
                 otherwise the ``metas.pea_workspace`` is returned
         """
-        work_dir = self.pea_workspace if self.separated_workspace else self.workspace  # type: str
+        work_dir = self.pea_workspace if self.separated_workspace and self.pea_id != -1 else self.workspace  # type: str
         return work_dir
 
     def get_file_from_workspace(self, name: str) -> str:
