@@ -6,14 +6,12 @@ import base64
 import copy
 import os
 import threading
-import time
 from collections import OrderedDict, defaultdict
 from contextlib import ExitStack
 from typing import Optional, Union, Tuple, List, Set, Dict, TextIO, TypeVar
 from urllib.request import Request, urlopen
 
 from .builder import build_required, _build_flow, _optimize_flow, _hanging_pods
-from .. import JINA_GLOBAL
 from ..clients import Client, WebSocketClient
 from ..enums import FlowBuildLevel, PodRoleType, FlowInspectType
 from ..excepts import FlowTopologyError, FlowMissingPodError
@@ -21,7 +19,6 @@ from ..helper import colored, \
     get_public_ip, get_internal_ip, typename, ArgNamespace
 from ..jaml import JAML, JAMLCompatible
 from ..logging import JinaLogger
-from ..logging.sse import start_sse_logger
 from ..parsers import set_client_cli_parser, set_gateway_parser, set_pod_parser
 
 __all__ = ['BaseFlow', 'FlowLike']
@@ -231,7 +228,6 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
             num_part=len(needs)
         ))
 
-
         parser = set_pod_parser()
         if pod_role == PodRoleType.GATEWAY:
             parser = set_gateway_parser()
@@ -390,8 +386,6 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         super().__exit__(exc_type, exc_val, exc_tb)
-        if self.args.logserver:
-            self._stop_log_server()
 
         # unset all envs to avoid any side-effect
         if self._env:
@@ -403,40 +397,6 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
             f'flow is closed and all resources should be released already, current build level is {self._build_level}')
         self.logger.close()
 
-    def _stop_log_server(self):
-        import urllib.request
-        try:
-            # it may have been shutdown from the outside
-            urllib.request.urlopen(JINA_GLOBAL.logserver.shutdown, timeout=5)
-        except Exception as ex:
-            self.logger.info(f'Failed to connect to shutdown log sse server: {ex!r}')
-
-    def _start_log_server(self):
-        try:
-            import urllib.request
-            import flask, flask_cors
-            try:
-                with open(self.args.logserver_config) as fp:
-                    log_config = JAML.load(fp)
-                self._sse_logger = threading.Thread(name='sentinel-sse-logger',
-                                                    target=start_sse_logger, daemon=True,
-                                                    args=(log_config,
-                                                          self.args.log_id,
-                                                          self.yaml_spec))
-                self._sse_logger.start()
-                time.sleep(1)
-                response = urllib.request.urlopen(JINA_GLOBAL.logserver.ready, timeout=5)
-                if response.status == 200:
-                    self.logger.success(f'logserver is started and available at {JINA_GLOBAL.logserver.address}')
-            except Exception as ex:
-                self.logger.error(f'Could not start logserver because of {ex!r}')
-        except ModuleNotFoundError:
-            self.logger.error(
-                f'sse logserver can not start because of "flask" and "flask_cors" are missing, '
-                f'use pip install "jina[http]" (with double quotes) to install the dependencies')
-        except Exception as ex:
-            self.logger.error(f'logserver fails to start: {ex!r}')
-
     def start(self):
         """Start to run all Pods in this Flow.
 
@@ -449,10 +409,6 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
         if self._build_level.value < FlowBuildLevel.GRAPH.value:
             self.build(copy_flow=False)
 
-        if self.args.logserver:
-            self.logger.info('starting logserver...')
-            self._start_log_server()
-
         # set env only before the pod get started
         if self._env:
             for k, v in self._env.items():
@@ -460,6 +416,9 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
 
         for v in self._pod_nodes.values():
             self.enter_context(v)
+            if not v.is_ready:
+                self.logger.error(f'Pod {v!r} can not be started, Flow is aborted')
+                break
 
         self.logger.info(f'{self.num_pods} Pods (i.e. {self.num_peas} Peas) are running in this Flow')
 
