@@ -16,7 +16,7 @@ class CenterImageCropper(BaseCrafter):
     """
 
     def __init__(self,
-                 target_size: Union[Tuple[int, int], int],
+                 target_size: Union[Tuple[int, int], int] = 224,
                  channel_axis: int = -1,
                  *args,
                  **kwargs):
