@@ -25,11 +25,35 @@ class KVAppendAction(argparse.Action):
                 try:
                     (k, v) = value.split('=', 2)
                 except ValueError:
-                    raise argparse.ArgumentError(f'could not parse argument \"{values[0]}\" as k=v format')
+                    raise argparse.ArgumentTypeError(f'could not parse argument \"{values[0]}\" as k=v format')
                 d[k] = v
         setattr(args, self.dest, d)
 
 
+class DockerKwargsAppendAction(argparse.Action):
+    """
+    argparse action to split an argument into KEY: VALUE form
+    on the first : and append to a dictionary.
+    This is used for setting up arbitrary kwargs for docker sdk
+    """
+
+    def __call__(self, parser, args, values, option_string=None):
+        import json
+        d = getattr(args, self.dest) or {}
+
+        for value in values:
+            try:
+                d.update(json.loads(value))
+            except json.JSONDecodeError:
+                try:
+                    (k, v) = value.split(':', 1)
+                except ValueError:
+                    raise argparse.ArgumentTypeError(f'could not parse argument \"{values[0]}\" as k:v format')
+                # transform from text to actual type (int, list, etc...)
+                d[k] = json.loads(v)
+        setattr(args, self.dest, d)
+
+
 class _ColoredHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
     class _Section(object):
 
@@ -72,22 +96,22 @@ class _ColoredHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
         self._current_section = section
 
     def _get_help_string(self, action):
-        help = action.help
+        help_string = action.help
         if '%(default)' not in action.help:
             if action.default is not argparse.SUPPRESS:
                 from ..helper import colored
                 defaulting_nargs = [argparse.OPTIONAL, argparse.ZERO_OR_MORE]
                 if isinstance(action, argparse._StoreTrueAction):
 
-                    help += colored(' (default: %s)' % (
+                    help_string += colored(' (default: %s)' % (
                         'enabled' if action.default else f'disabled, use "--{action.dest}" to enable it'),
                                     attrs=['dark'])
                 elif action.choices:
                     choices_str = f'{{{", ".join([str(c) for c in action.choices])}}}'
-                    help += colored(' (choose from: ' + choices_str + '; default: %(default)s)', attrs=['dark'])
+                    help_string += colored(' (choose from: ' + choices_str + '; default: %(default)s)', attrs=['dark'])
                 elif action.option_strings or action.nargs in defaulting_nargs:
-                    help += colored(' (type: %(type)s; default: %(default)s)', attrs=['dark'])
-        return help
+                    help_string += colored(' (type: %(type)s; default: %(default)s)', attrs=['dark'])
+        return help_string
 
     def _get_default_metavar_for_optional(self, action):
         return ''
@@ -119,13 +143,13 @@ class _ColoredHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
         else:
             result = default_metavar
 
-        def format(tuple_size):
+        def formatter(tuple_size):
             if isinstance(result, tuple):
                 return result
             else:
                 return (result,) * tuple_size
 
-        return format
+        return formatter
 
     def _fill_text(self, text, width, indent):
         return ''.join(indent + line for line in text.splitlines(keepends=True))
