@@ -209,6 +209,7 @@ class BasePod(ExitStack):
 
     def __exit__(self, exc_type, exc_val, exc_tb) -> None:
         super().__exit__(exc_type, exc_val, exc_tb)
+        self.join()
 
     def join(self):
         """Wait until all peas exit"""
@@ -227,6 +228,8 @@ class BasePod(ExitStack):
                 args.runtime_cls = 'RESTRuntime'
             else:
                 args.runtime_cls = 'GRPCRuntime'
+        if 'parallel' in args and args.parallel == 1:
+            args.separated_workspace = False
 
     def connect_to_tail_of(self, pod: 'BasePod'):
         """Eliminate the head node by connecting prev_args node directly to peas """
@@ -260,3 +263,8 @@ class BasePod(ExitStack):
             self.deducted_tail = pod.head_args
         else:
             raise ValueError('the current pod has no tail router, deducting the tail is confusing')
+
+    @property
+    def is_ready(self) -> bool:
+        """A Pod is ready when all the Peas it contains are ready"""
+        return all(p.is_ready.is_set() for p in self.peas)
\ No newline at end of file
