@@ -29,10 +29,13 @@ class ContainerRuntime(ZMQRuntime):
     def teardown(self):
         self._container.stop()
 
-    def run_forever(self):
+    def _stream_logs(self):
         for line in self._container.logs(stream=True):
             self.logger.info(line.strip().decode())
 
+    def run_forever(self):
+        self._stream_logs()
+
     def _set_network_for_dind_linux(self):
         import docker
         # recompute the control_addr, do not assign client, since this would be an expensive object to
@@ -75,8 +78,9 @@ class ContainerRuntime(ZMQRuntime):
         # this prevent setting containerPea twice
         from ....parsers import set_pea_parser
         non_defaults = ArgNamespace.get_non_defaults_args(self.args, set_pea_parser(),
-                                                          taboo={'uses', 'entrypoint',
-                                                                 'volumes', 'pull_latest', 'runtime_cls'})
+                                                          taboo={'uses', 'entrypoint', 'volumes',
+                                                                 'pull_latest', 'runtime_cls',
+                                                                 'docker_kwargs'})
 
         if self.args.pull_latest:
             self.logger.warning(f'pulling {uses_img}, this could take a while. if you encounter '
@@ -96,9 +100,14 @@ class ContainerRuntime(ZMQRuntime):
                     f'"uses_internal" {self.args.uses_internal} is not like a path, please check it')
         if self.args.volumes:
             for p in self.args.volumes:
-                Path(os.path.abspath(p)).mkdir(parents=True, exist_ok=True)
-                _p = '/' + os.path.basename(p)
-                _volumes[os.path.abspath(p)] = {'bind': _p, 'mode': 'rw'}
+                paths = p.split(':')
+                local_path = paths[0]
+                Path(os.path.abspath(local_path)).mkdir(parents=True, exist_ok=True)
+                if len(paths) == 2:
+                    container_path = paths[1]
+                else:
+                    container_path = '/' + os.path.basename(p)
+                _volumes[os.path.abspath(local_path)] = {'bind': container_path, 'mode': 'rw'}
 
         _expose_port = [self.args.port_ctrl]
         if self.args.socket_in.is_bind:
@@ -108,6 +117,9 @@ class ContainerRuntime(ZMQRuntime):
 
         _args = ArgNamespace.kwargs2list(non_defaults)
         ports = {f'{v}/tcp': v for v in _expose_port} if not self._net_mode else None
+
+        docker_kwargs = self.args.docker_kwargs or {}
+
         self._container = client.containers.run(uses_img,
                                                 _args,
                                                 detach=True,
@@ -116,13 +128,13 @@ class ContainerRuntime(ZMQRuntime):
                                                 name=slugify(self.name),
                                                 volumes=_volumes,
                                                 network_mode=self._net_mode,
-                                                entrypoint=self.args.entrypoint)
+                                                entrypoint=self.args.entrypoint,
+                                                **docker_kwargs)
 
         if replay:
             # when replay is on, it means last time it fails to start
             # therefore we know the loop below wont block the main process
-            for line in self._container.logs(stream=True):
-                self.logger.info(line.strip().decode())
+            self._stream_logs()
 
         client.close()
 
