@@ -320,18 +320,19 @@ class ZmqStreamlet(Zmqlet):
             for s in self.opened_socks:
                 s.flush()
             super().close()
-            try:
-                self.io_loop.stop()
-                # Replace handle events function, to skip
-                # None event after sockets are closed.
-                if hasattr(self.in_sock, '_handle_events'):
-                    self.in_sock._handle_events = lambda *args, **kwargs: None
-                if hasattr(self.out_sock, '_handle_events'):
-                    self.out_sock._handle_events = lambda *args, **kwargs: None
-                if hasattr(self.ctrl_sock, '_handle_events'):
-                    self.ctrl_sock._handle_events = lambda *args, **kwargs: None
-            except AttributeError as e:
-                self.logger.error(f'failed to stop. {e!r}')
+            if hasattr(self, 'io_loop'):
+                try:
+                    self.io_loop.stop()
+                    # Replace handle events function, to skip
+                    # None event after sockets are closed.
+                    if hasattr(self.in_sock, '_handle_events'):
+                        self.in_sock._handle_events = lambda *args, **kwargs: None
+                    if hasattr(self.out_sock, '_handle_events'):
+                        self.out_sock._handle_events = lambda *args, **kwargs: None
+                    if hasattr(self.ctrl_sock, '_handle_events'):
+                        self.ctrl_sock._handle_events = lambda *args, **kwargs: None
+                except AttributeError as e:
+                    self.logger.error(f'failed to stop. {e!r}')
 
     def pause_pollin(self):
         """Remove :attr:`in_sock` from the poller """
@@ -593,7 +594,7 @@ def _init_socket(ctx: 'zmq.Context', host: str, port: Optional[int],
                 try:
                     sock.bind(f'tcp://{host}:{port}')
                 except zmq.error.ZMQError:
-                    default_logger.error(f'error when binding port {port} to {host}')
+                    default_logger.error(f'error when binding port {port} to {host}, this port is occupied.')
                     raise
     else:
         if port is None:
